@@ -1,34 +1,33 @@
 import requests
 
-class APPOINTMENTS(object):
+class APPOINTMENTS():
 
-    def __init__(self, api_key, appointment_startdate=None, appointment_enddate=None, appointment_id=None, fake_count=1, **kwargs):
+    def __init__(self, api_key, appointment_startdate=None, appointment_enddate=None, appointment_id=None, **kwargs):
         self.appointment_startdate = appointment_startdate
         self.appointment_enddate = appointment_enddate
         self.appointment_id = appointment_id
-        self.fake_count = fake_count
         assert isinstance(api_key, str), 'You must provide a valid API Key'
         self.api_key = api_key
 
-    @classmethod
-    def appointment_list(cls, api_key, appointment_startdate=None, appointment_enddate=None):
+    def appointment_list(self, appointment_startdate):
         """
             Appointment startdate format: YYYY-MM-DD
             Appointment endate format: YYYY-MM-DD
         """
+        print('appointment_startdate:', appointment_startdate)
         path = 'https://drchrono.com/api/appointments?since={}'.format(appointment_startdate)
         list_response = []
         while path:
-            data = requests.get(path, headers={'Authorization': 'Bearer ' + api_key}).json()
+            data = requests.get(path, headers={'Authorization': 'Bearer ' + self.api_key}).json()
             list_response.extend(data['results'])
             path = data['next'] # A JSON null on the last page
+        
         return list_response
 
-    @classmethod
-    def appointment_single(cls, api_key, appointment_id):
+    def appointment_single(self, appointment_id):
         path = 'https://drchrono.com/api/appointments/{}'.format(appointment_id)
         try: 
-            data = requests.get(path, headers={'Authorization': 'Bearer ' + api_key})
+            data = requests.get(path, headers={'Authorization': 'Bearer ' + self.api_key})
             data_json = data.json()
             return data_json
         except Exception as e:
